┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinmainwindow.h
diff options
context:
space:
mode:
authorEmmanuel Pescosta <[email protected]>2015-04-27 12:55:53 +0200
committerEmmanuel Pescosta <[email protected]>2015-04-27 12:55:53 +0200
commit5acfb27760f3da1d4f794e820008f8a4c8ff7533 (patch)
tree8e35c3dd495c0c7d999fadbf9e25b66433572111 /src/dolphinmainwindow.h
parent06776451a72c395fca4b40196a6617366167ad66 (diff)
Simplify startup split view handling
* Instead of setting and resetting GeneralSettings's split view option, just pass it on to openFiles/openDirectories. * Require at least one url in openFiles/openDirectories REVIEW: 123395
Diffstat (limited to 'src/dolphinmainwindow.h')
-rw-r--r--src/dolphinmainwindow.h20
1 files changed, 8 insertions, 12 deletions
diff --git a/src/dolphinmainwindow.h b/src/dolphinmainwindow.h
index 5066657ef..7003e9474 100644
--- a/src/dolphinmainwindow.h
+++ b/src/dolphinmainwindow.h
@@ -71,17 +71,18 @@ public:
DolphinViewContainer* activeViewContainer() const;
/**
* Opens each directory in \p dirs in a separate tab. If the "split view"
* option is enabled, 2 directories are collected within one tab.
*/
- void openDirectories(const QList<QUrl> &dirs);
+ void openDirectories(const QList<QUrl> &dirs, bool splitView);
/**
- * Opens the directory which contains the files \p files
- * and selects all files (implements the --select option
- * of Dolphin).
+ * Opens the directories which contain the files \p files and selects all files.
+ * If \a splitView is set, 2 directories are collected within one tab.
+ * \pre \a files must contain at least one url.
*/
- void openFiles(const QList<QUrl>& files);
+ void openFiles(const QList<QUrl>& files, bool splitView);
/**
* Returns the 'Create New...' sub menu which also can be shared
@@ -119,11 +120,6 @@ public slots:
/** Stores all settings and quits Dolphin. */
void quit();
- /**
- * Opens a new tab showing the URL \a url and activates the tab.
- */
- void openNewActivatedTab(const QUrl& url);
-
signals:
/**
* Is sent if the selection of the currently active view has
@@ -71,17 +71,18 @@ public:
DolphinViewContainer* activeViewContainer() const;
/**
- * Opens each directory in \p dirs in a separate tab. If the "split view"
- * option is enabled, 2 directories are collected within one tab.
+ * Opens each directory in \p dirs in a separate tab. If \a splitView is set,
+ * 2 directories are collected within one tab.
+ * \pre \a dirs must contain at least one url.
*/